==> netdata-1.8.0.tar.xz: netdata-1.8.0/LICENSE-REDISTRIBUTED.md <==
# Netdata

Copyright 2016-2017, Costa Tsaousis.
Released under [GPL v3 or later](http://www.gnu.org/licenses/gpl-3.0.en.html).

---

## Re-distributed software

Netdata re-distributes the following third party software.
We decided to re-distribute all these, instead of using them
through a CDN, to allow netdata work in cases where internet
connectivity is not available.


- [Dygraphs](http://dygraphs.com/)

    Copyright 2009, Dan Vanderkam
    [MIT License](http://dygraphs.com/legal.html)


- [jQuery Sparklines](http://omnipotent.net/jquery.sparkline/)

    Copyright 2009-2012, Splunk Inc.
    [New BSD License](http://opensource.org/licenses/BSD-3-Clause)


- [Peity](http://benpickles.github.io/peity/)

    Copyright 2009-2015, Ben Pickles
    [MIT License](https://github.com/benpickles/peity/blob/master/MIT-LICENCE)
    

- [Easy Pie Chart](https://rendro.github.io/easy-pie-chart/)

    Copyright 2013, Robert Fleischmann
    [MIT License](https://github.com/rendro/easy-pie-chart/blob/master/LICENSE)


- [Guage.js](http://bernii.github.io/gauge.js/)

    Copyright, Bernard Kobos
    [MIT License](http://bernii.github.io/gauge.js/)


- [jQuery](https://jquery.org/)

    Copyright 2015, jQuery Foundation
    [MIT License](https://jquery.org/license/)


- [Bootstrap](http://getbootstrap.com/getting-started/)

    Copyright 2015, Twitter
    [MIT License](http://getbootstrap.com/getting-started/#license-faqs)


- [Bootstrap Toggle](http://www.bootstraptoggle.com/)

    Copyright (c) 2011-2014 Min Hur, The New York Times Company
    [MIT License](https://github.com/minhur/bootstrap-toggle/blob/master/LICENSE)


- [bootstrap-table](http://bootstrap-table.wenzhixin.net.cn/)

    Copyright (c) 2012-2016 Zhixin Wen <wenzhixin2010@gmail.com>
    [MIT License](https://github.com/wenzhixin/bootstrap-table/blob/master/LICENSE)


- [tableExport.jquery.plugin](https://github.com/hhurz/tableExport.jquery.plugin)

    Copyright (c) 2015,2016 hhurz
    [MIT License](http://rawgit.com/hhurz/tableExport.jquery.plugin/master/tableExport.js)


- [perfect-scrollbar](https://jamesflorentino.github.io/nanoScrollerJS/)

    Copyright 2016, Hyunje Alex Jun and other contributors
    [MIT License](https://github.com/noraesae/perfect-scrollbar/blob/master/LICENSE)


- [FontAwesome](https://fortawesome.github.io/Font-Awesome/)

    Created by Dave Gandy
    Font license: [SIL OFL 1.1](http://scripts.sil.org/OFL)
    CSS license: [MIT License](http://opensource.org/licenses/mit-license.html)


- [IconsDB.com Icons](http://www.iconsdb.com/soylent-red-icons/seo-performance-icon.html)

    Icons provided as CC0 1.0 Universal (CC0 1.0) Public Domain Dedication


- [morris.js](http://morrisjs.github.io/morris.js/)

    Copyright 2013, Olly Smith
    [Simplified BSD License](http://morrisjs.github.io/morris.js/)


- [Raphaël](http://raphaeljs.com/)

    Copyright 2008, Dmitry Baranovskiy
    [MIT License](http://raphaeljs.com/license.html)
    

- [C3](http://c3js.org/)

    Copyright 2013, Masayuki Tanaka
    [MIT License](https://github.com/masayuki0812/c3/blob/master/LICENSE)
    

- [D3](http://d3js.org/)

    Copyright 2015, Mike Bostock
    [BSD License](http://opensource.org/licenses/BSD-3-Clause)
    
    
- [node-extend](https://github.com/justmoon/node-extend)

    Copyright 2014, Stefan Thomas
    [MIT License](https://github.com/justmoon/node-extend/blob/master/LICENSE)
    

- [node-net-snmp](https://github.com/stephenwvickers/node-net-snmp)

    Copyright 2013, Stephen Vickers
    [MIT License](https://github.com/stephenwvickers/node-net-snmp)
    

- [node-asn1-ber](https://github.com/stephenwvickers/node-asn1-ber)

    Copyright 2017, Stephen Vickers
    Copyright 2011, Mark Cavage
    [MIT License](https://github.com/stephenwvickers/node-asn1-ber)
    

- [pixl-xml](https://github.com/jhuckaby/pixl-xml)

    Copyright 2015, Joseph Huckaby
    [MIT License](https://github.com/jhuckaby/pixl-xml)
    
- [sensors](https://github.com/paroj/sensors.py)

    Copyright 2014, Pavel Rojtberg
    [LGPL 2.1 License](http://opensource.org/licenses/LGPL-2.1)

- [PyYAML](https://bitbucket.org/blackjack/pysensors)

    Copyright 2006, Kirill Simonov
    [MIT License](http://pyyaml.org)

- [urllib3](https://github.com/shazow/urllib3)

    Copyright 2008-2016 Andrey Petrov and [contributors](https://github.com/shazow/urllib3/blob/master/CONTRIBUTORS.txt)
    [MIT License](https://github.com/shazow/urllib3/blob/master/LICENSE.txt)

==> netdata_1.9.0+dfsg.orig.tar.xz: netdata-1.9.0/LICENSE-REDISTRIBUTED.md <==
# Netdata

Copyright 2016-2017, Costa Tsaousis.
Released under [GPL v3 or later](http://www.gnu.org/licenses/gpl-3.0.en.html).

---

## Re-distributed software

Netdata re-distributes the following third party software.
We decided to re-distribute all these, instead of using them
through a CDN, to allow netdata work in cases where internet
connectivity is not available.


- [Dygraphs](http://dygraphs.com/)

    Copyright 2009, Dan Vanderkam
    [MIT License](http://dygraphs.com/legal.html)


- [jQuery Sparklines](http://omnipotent.net/jquery.sparkline/)

    Copyright 2009-2012, Splunk Inc.
    [New BSD License](http://opensource.org/licenses/BSD-3-Clause)


- [Peity](http://benpickles.github.io/peity/)

    Copyright 2009-2015, Ben Pickles
    [MIT License](https://github.com/benpickles/peity/blob/master/MIT-LICENCE)
    

- [Easy Pie Chart](https://rendro.github.io/easy-pie-chart/)

    Copyright 2013, Robert Fleischmann
    [MIT License](https://github.com/rendro/easy-pie-chart/blob/master/LICENSE)


- [Guage.js](http://bernii.github.io/gauge.js/)

    Copyright, Bernard Kobos
    [MIT License](http://bernii.github.io/gauge.js/)


- [jQuery](https://jquery.org/)

    Copyright 2015, jQuery Foundation
    [MIT License](https://jquery.org/license/)


- [Bootstrap](http://getbootstrap.com/getting-started/)

    Copyright 2015, Twitter
    [MIT License](http://getbootstrap.com/getting-started/#license-faqs)

- [Bootstrap-slider](http://seiyria.com/bootstrap-slider/)

    Copyright 2017 Kyle Kemp, Rohit Kalkur, and contributors
    [MIT License](https://github.com/seiyria/bootstrap-slider/blob/master/LICENSE.md)

- [Bootstrap Toggle](http://www.bootstraptoggle.com/)

    Copyright (c) 2011-2014 Min Hur, The New York Times Company
    [MIT License](https://github.com/minhur/bootstrap-toggle/blob/master/LICENSE)


- [bootstrap-table](http://bootstrap-table.wenzhixin.net.cn/)

    Copyright (c) 2012-2016 Zhixin Wen <wenzhixin2010@gmail.com>
    [MIT License](https://github.com/wenzhixin/bootstrap-table/blob/master/LICENSE)


- [tableExport.jquery.plugin](https://github.com/hhurz/tableExport.jquery.plugin)

    Copyright (c) 2015,2016 hhurz
    [MIT License](http://rawgit.com/hhurz/tableExport.jquery.plugin/master/tableExport.js)


- [perfect-scrollbar](https://jamesflorentino.github.io/nanoScrollerJS/)

    Copyright 2016, Hyunje Alex Jun and other contributors
    [MIT License](https://github.com/noraesae/perfect-scrollbar/blob/master/LICENSE)


- [FontAwesome](https://fortawesome.github.io/Font-Awesome/)

    Created by Dave Gandy
    Font license: [SIL OFL 1.1](http://scripts.sil.org/OFL)
    CSS license: [MIT License](http://opensource.org/licenses/mit-license.html)


- [IconsDB.com Icons](http://www.iconsdb.com/soylent-red-icons/seo-performance-icon.html)

    Icons provided as CC0 1.0 Universal (CC0 1.0) Public Domain Dedication


- [morris.js](http://morrisjs.github.io/morris.js/)

    Copyright 2013, Olly Smith
    [Simplified BSD License](http://morrisjs.github.io/morris.js/)


- [Raphaël](http://raphaeljs.com/)

    Copyright 2008, Dmitry Baranovskiy
    [MIT License](http://raphaeljs.com/license.html)
    

- [C3](http://c3js.org/)

    Copyright 2013, Masayuki Tanaka
    [MIT License](https://github.com/masayuki0812/c3/blob/master/LICENSE)
    

- [D3](http://d3js.org/)

    Copyright 2015, Mike Bostock
    [BSD License](http://opensource.org/licenses/BSD-3-Clause)
    
    
- [node-extend](https://github.com/justmoon/node-extend)

    Copyright 2014, Stefan Thomas
    [MIT License](https://github.com/justmoon/node-extend/blob/master/LICENSE)
    

- [node-net-snmp](https://github.com/stephenwvickers/node-net-snmp)

    Copyright 2013, Stephen Vickers
    [MIT License](https://github.com/stephenwvickers/node-net-snmp)
    

- [node-asn1-ber](https://github.com/stephenwvickers/node-asn1-ber)

    Copyright 2017, Stephen Vickers
    Copyright 2011, Mark Cavage
    [MIT License](https://github.com/stephenwvickers/node-asn1-ber)
    

- [pixl-xml](https://github.com/jhuckaby/pixl-xml)

    Copyright 2015, Joseph Huckaby
    [MIT License](https://github.com/jhuckaby/pixl-xml)
    
- [sensors](https://github.com/paroj/sensors.py)

    Copyright 2014, Pavel Rojtberg
    [LGPL 2.1 License](http://opensource.org/licenses/LGPL-2.1)

- [PyYAML](https://bitbucket.org/blackjack/pysensors)

    Copyright 2006, Kirill Simonov
    [MIT License](http://pyyaml.org)

- [urllib3](https://github.com/shazow/urllib3)

    Copyright 2008-2016 Andrey Petrov and [contributors](https://github.com/shazow/urllib3/blob/master/CONTRIBUTORS.txt)
    [MIT License](https://github.com/shazow/urllib3/blob/master/LICENSE.txt)

- [lz-string](http://pieroxy.net/blog/pages/lz-string/index.html)

    Copyright 2013 Pieroxy
    [WTFPL License](http://pieroxy.net/blog/pages/lz-string/index.html#inline_menu_10)

- [pako](http://nodeca.github.io/pako/)

    Copyright 2014-2017 Vitaly Puzrin and Andrei Tuputcyn
    [MIT License](https://github.com/nodeca/pako/blob/master/LICENSE)
